encode_img_writer

Function encode_img_writer 

pub fn encode_img_writer<T: Write>(
    data: ImageData,
    typ: ImageOutputType,
    file: &mut T,
    config: &ExtraConfig,
) -> Result<()>
Available on crate feature image only.
Encodes an image to the specified format and writes it to a writer.

  • data - The image data to encode.
  • typ - The output image format.
  • filename - The path of the file to write the encoded image to.
  • config - Extra configuration.